<?php
/**
 * Plugin Name:     Holler Box Sales Notifications
 * Plugin URI:      http://hollerwp.com
 * Description:     Show sales notifications to visitors, supports EDD and WooCommerce.
 * Version:         0.1
 * Author:          Scott Bolinger
 * Author URI:      http://hollerwp.com
 * Text Domain:     hollerbox-sales
 *
 * @author          Scott Bolinger
 * @copyright       Copyright (c) Scott Bolinger 2017
 *
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

if( !class_exists( 'Holler_Box_Sales' ) ) {

    /**
     * Main Holler_Box_Sales class
     *
     * @since       0.1.0
     */
    class Holler_Box_Sales {

        /**
         * @var         Holler_Box_Sales $instance The one true Holler_Box_Sales
         * @since       0.1.0
         */
        private static $instance;


        /**
         * Get active instance
         *
         * @access      public
         * @since       0.1.0
         * @return      object self::$instance The one true Holler_Box_Sales
         */
        public static function instance() {
            if( !self::$instance ) {
                self::$instance = new Holler_Box_Sales();
                self::$instance->setup_constants();
                self::$instance->includes();
                self::$instance->load_textdomain();
                self::$instance->hooks();
            }

            return self::$instance;
        }


        /**
         * Setup plugin constants
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         */
        private function setup_constants() {
            // Plugin version
            define( 'Holler_Box_Sales_VER', '0.1' );

            // Plugin path
            define( 'Holler_Box_Sales_DIR', plugin_dir_path( __FILE__ ) );

            // Plugin URL
            define( 'Holler_Box_Sales_URL', plugin_dir_url( __FILE__ ) );
        }


        /**
         * Include necessary files
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         */
        private function includes() {

            require_once Holler_Box_Sales_DIR . 'includes/class-holler-sales-functions.php';
            
        }


        /**
         * Run action and filter hooks
         *
         * @access      private
         * @since       0.1.0
         * @return      void
         *
         *
         */
        private function hooks() {

        }


        /**
         * Internationalization
         *
         * @access      public
         * @since       0.1.0
         * @return      void
         */
        public function load_textdomain() {

            load_plugin_textdomain( 'hollerbox-sales' );
            
        }

    }
} // End if class_exists check


/**
 * The main function responsible for returning the one true EDD_Metrics
 * instance to functions everywhere
 *
 * @since       0.1.0
 * @return      Holler_Box_Sales::instance()
 *
 */
function holler_box_sales_load() {
    return Holler_Box_Sales::instance();
}
add_action( 'plugins_loaded', 'holler_box_sales_load' );


/**
 * The activation hook is called outside of the singleton because WordPress doesn't
 * register the call from within the class, since we are preferring the plugins_loaded
 * hook for compatibility, we also can't reference a function inside the plugin class
 * for the activation function. If you need an activation function, put it here.
 *
 * @since       0.1.0
 * @return      void
 */
function holler_box_sales_activation() {
    /* Activation functions here */
}
register_activation_hook( __FILE__, 'holler_box_sales_activation' );