<?php
/**
 * Holler Box Pro Functions
 * @since       0.1.0
 */


// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

if( !class_exists( 'Holler_Sales_Functions' ) ) {

    /**
     * Holler_Sales_Functions class
     *
     * @since       0.2.0
     */
    class Holler_Sales_Functions {

        /**
         * @var         Holler_Sales_Functions $instance The one true Holler_Sales_Functions
         * @since       0.2.0
         */
        private static $instance;
        public static $errorpath = '../php-error-log.php';
        public static $active = array();
        // sample: error_log("meta: " . $meta . "\r\n",3,self::$errorpath);

        /**
         * Get active instance
         *
         * @access      public
         * @since       0.2.0
         * @return      object self::$instance The one true Holler_Sales_Functions
         */
        public static function instance() {
            if( !self::$instance ) {
                self::$instance = new Holler_Sales_Functions();
                self::$instance->hooks();
            }

            return self::$instance;
        }


        /**
         * Include necessary files
         *
         * @access      private
         * @since       0.2.0
         * @return      void
         */
        private function hooks() {

            if( class_exists('Easy_Digital_Downloads') ) {
                add_filter( 'hollerbox_content', array( $this, 'edd_sale' ), 10, 2 );
            } elseif( class_exists('WooCommerce') ) {
                add_action( 'hollerbox_content', array( $this, 'woocommerce_sale' ), 10, 2 );
            }

            add_action( 'hwp_settings_page', array( $this, 'add_settings') );

        }

        /**
         * Add latest EDD sale to Hollerbox, specified by ID in setting
         *
         * @since       0.1.0
         * @return      void
         */
        public function edd_sale( $content, $id ) {

            // this is the ID where we should show sales notifications
            $setting_id = get_option( 'hwp_sale_id' );
    
            // $id is the notification ID, not the current page ID
            if( !$setting_id || $id != $setting_id )
                return $content;

            $edd_payment = get_post_type_object( 'edd_payment' );
            $args = array(
                'post_type' => 'edd_payment',
                'post_status' => array( 'publish' ),
                'posts_per_page' => 1
            );

            // The Query
            $the_query = new WP_Query( $args );

            if ( $the_query->have_posts() ) {
                while ( $the_query->have_posts() ) {
                    $the_query->the_post();
                    $download_meta = get_post_meta( get_the_ID(), '_edd_payment_meta', 1 );
                    $download_id = $download_meta['downloads'][0]['id'];
                    $customer_email = $download_meta['user_info']['email'];
                 
                    $download = edd_get_download( $download_id );
                    $content = get_avatar( $customer_email, 50 );
                    $content .= $download_meta['user_info']['first_name'] . ' just purchased <a href="' . get_permalink( $download_id ) . '">' . $download->post_title . '</a>';
                }
                wp_reset_postdata();
            }

            return $content;

        }

        /**
         * Add latest Woo sale to Hollerbox, specified by ID in setting
         *
         * @since       0.1.0
         * @return      void
         */
        public function woocommerce_sale( $content, $id ) {

            // this is the ID where we should show sales notifications
            $setting_id = get_option( 'hwp_sale_id' );
    
            // $id is the notification ID, not the current page ID
            if( !$setting_id || $id != $setting_id )
                return $content;

            $args = array( 
                'status' => 'wc-completed',
                'type' => 'shop_order',
                'limit' => 1
             );

            $order = wc_get_orders( $args )[0];
            $id = $order->get_id();

            $items = $order->get_items();

            foreach ( $items as $item ) {
                $name = $item['name'];
                $product_id = $item['product_id'];
            }

            $first_name = $order->get_billing_first_name();
            $email = $order->get_billing_email();

            $content = get_avatar( $email, 50 );
            $content .= $first_name . ' just purchased <a href="' . get_permalink( $product_id ) . '">' . $name . '</a>';

            return $content;

        }

        /**
         * Add setting for ID. This will filter the content for a hollerbox to display EDD sales.
         *
         * @since       0.1.0
         * @return      void
         */
        public function add_settings() {

            if( isset( $_POST['hwp_sale_id'] ) ) {
                update_option( 'hwp_sale_id', sanitize_text_field( $_POST['hwp_sale_id'] ) );
            }

            ?>
            <h3><?php _e('Sales Notifications', 'hollerbox-edd'); ?></h3>

            <p><?php _e('Enter ID of Holler Box to show sale notifications.', 'hollerbox-edd'); ?></p>

            <?php 

            $pro_status = get_option('hwp_pro_edd_license_status');

            if( empty( $pro_status ) || $pro_status != 'valid' ) {
                echo 'Please enter your Holler Box Pro license key, save, then click activate.';
            } else {
                ?>
                <input id="hwp_sale_id" name="hwp_sale_id" value="<?php echo esc_html( get_option( 'hwp_sale_id' ) ); ?>" type="text" size="10" />
                <?php
            }
        }

    }

    $holler_sales_functions = new Holler_Sales_Functions();
    $holler_sales_functions->instance();

} // end class_exists check